@@ -403,7 +403,7 @@ draw (CCCHHDoorIsDesktopWidget *self, cairo_t *cr)
 
 // debug
 if (!self->timeout_handler) {
-	cairo_set_source_rgba(cr, 1, 0, 0, 0.47);
+	cairo_set_source_rgba(cr, 0.15, 0.15, 0.15, 0.47);
 	cairo_mask_surface(cr, self->image_current, 5, 5);
 }
 
@@ -722,12 +722,20 @@ static void
 fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 	gulong new_change_ts, gulong new_report_ts)
 {
+	time_t timenow;
+
 	g_debug(WIDGET_NAME": fetch_update_process()");
 
 	self->current_state = new_state;
 	self->last_change_ts = new_change_ts;
 	self->last_report_ts = new_report_ts;
 
+	time (&timenow);
+	if (timenow != -1 && self->last_report_ts && (timenow - self->last_report_ts) > REPORT_TIMEOUT) {
+		g_message(WIDGET_NAME": fetch_update_process: last_report_ts too old, forcing state to DOORIS_FNORD");
+		self->current_state = DOORIS_FNORD;
+	}
+
 	if (new_state == self->last_state) {
 		g_debug(WIDGET_NAME": state unchanged");
 
