@@ -10,6 +10,9 @@
 // gconf base path
 #define GCONF_DIR "/apps/maemo/ccchh-dooris-widget"
 
+// maximum report age in seconds
+#define REPORT_TIMEOUT 7200
+
 // async I/O timeouts
 #define TIMEOUT_CONNECT 5
 #define TIMEOUT_READ	30
